@@ -1,13 +1,12 @@
 #' Assess a package for the presence of a url field where bugs can be reported.
 #'
-#' @eval roxygen_assess_family("has_bug_reports_url",
+#' @eval roxygen_assess_family(
+#' "has_bug_reports_url",
 #' "a character value containing the BugReports field contents")
 #'
 #' @export
 assess_has_bug_reports_url <- function(x, ...) {
-  pkg_metric_eval(class = "pkg_metric_has_bug_reports_url", {
-    as.character(x$bug_reports_url)
-  })
+  UseMethod("assess_has_bug_reports_url")
 }
 
 # assign a friendly name for assess column
@@ -16,6 +15,15 @@ attr(assess_has_bug_reports_url,"label") <- "presence of a bug reports url in re
 
 
 
+#' @export
+assess_has_bug_reports_url.default <- function(x, ...) {
+  pkg_metric(class = "pkg_metric_has_bug_reports_url", {
+    length(x$bug_reports_url)
+  })
+}
+
+
+
 #' Score a package for the presence of a bug report url
 #'
 #' @eval roxygen_score_family("has_bug_reports_url")
@@ -25,8 +33,7 @@ attr(assess_has_bug_reports_url,"label") <- "presence of a bug reports url in re
 #'
 #' @export
 metric_score.pkg_metric_has_bug_reports_url <- function(x, ...) {
-  # Return a score of 1 if a bug report url is found, 0 otherwise
-  as.numeric(length(x) > 0)
+  as.numeric(x > 0)
 }
 
 attributes(metric_score.pkg_metric_has_bug_reports_url)$label <-
