@@ -4,8 +4,8 @@
 #' @family package reference cache
 #' @return a \code{pkg_ref} object
 #' @keywords internal
-pkg_ref_cache.r_cmd_check <- function (x, ...)
-{
+#' @noRd
+pkg_ref_cache.r_cmd_check <- function(x, ...) {
   UseMethod("pkg_ref_cache.r_cmd_check")
 }
 
@@ -18,6 +18,7 @@ pkg_ref_cache.r_cmd_check.default <- function (x, ...) {
 #' @inheritParams pkg_ref_cache
 #' @importFrom devtools check
 #' @return a \code{pkg_ref} object
+#' @noRd
 pkg_ref_cache.r_cmd_check.pkg_source <- function(x, ...){
   check_results <- devtools::check(x$path, quiet=TRUE)
   return(check_results)
